// *****************************************************************************
// File    : PDFChart.cs
// Author  : Utility Warrior, (c) 2005-2007
// Project : PDF Chart Creator (PDFChart) Dynamic Link Library
// Purpose : This file provides C# (CSharp) prototypes for all DLL functions
//
// Please refer to the accompanying documentation for full details.
// *****************************************************************************

using System;
using System.Text;
using System.Runtime.InteropServices;

public class Win32
{
	// *************************************************************************
	// This allows the support of multiple versions of a DLL (if and when
	// available) so that functions that might only be available in a later
	// version can then only be called if the returned version currently being 
	// used is one that supports those functions.
	//   
	// Return value: integer value representing the DLL version
	// a value of 100 is equivalent to version 1.00
	// *************************************************************************
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_GetDLLVersion();


	// *************************************************************************
	// Required
	// *************************************************************************
	[DllImport("PDFChart.dll")]
	public static extern void PDFC_License([MarshalAs(UnmanagedType.LPStr)] String code);
	// This is required to remove the "Evaluation Mode" message that is stamped 
	// over the top of every page in the output PDF document.   
	//
	// To purchase a license code please visit the Utility Warrior web site which 
	// has the latest information and prices on the licenses that are available. 
	//
	// Return value: none 


	public static UInt32 CHART_BAR_VERTICAL	     = 1;
	public static UInt32 CHART_BAR_HORIZONTAL	 = 2;
    public static UInt32 CHART_PIE_2D            = 3;
    public static UInt32 CHART_LINE_STANDARD     = 4;
    public static UInt32 CHART_LINE_STEPPED      = 5;
    public static UInt32 CHART_LINE_CURVED       = 6;
    public static UInt32 CHART_AREA_STANDARD     = 7;
    public static UInt32 CHART_AREA_STEPPED      = 8;
    public static UInt32 CHART_AREA_CURVED       = 9;
    
    [DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_Chart(UInt32 type);
	// Specify which chart type is to be generated.
	//
	// Return value:
	// 0 - success
	// 1 - invalid chart type


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_Page(UInt32 width, UInt32 height, double red, double green, double blue);
	// Specify page size and background color
	//
	// Width and height must be between 100 and 10000 inclusive
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
	//
	// Return value:
	// 0 - success
	// 1 - width invalid
	// 2 - height invalid
	// 3 - red invalid
	// 4 - green invalid
	// 5 - blue invalid


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_PageName([MarshalAs(UnmanagedType.LPStr)] String name, UInt32 landscape, double red, double green, double blue);
	// Specify page size using common name and background color
	//
	// name must be one of: A0, A1, A2, A3, A4, A5, B0, B1, B2, B3, B4, B5, Letter, Tabloid, Ledger, Executive, Legal, Folio, Foolscap, Quarto, Statement
	//
	// landscape value of 1 rotates the page size, 0 leaves it in portrait orientations
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
	//
	// Return value:
	// 0 - success
	// 1 - name invalid
	// 2 - red invalid
	// 3 - green invalid
	// 4 - blue invalid


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_DataSet([MarshalAs(UnmanagedType.LPStr)] String filename);
	// Load in chart data from an external file - either this and/or an appropriate chart
	// type datum function must be used in order to define at least one item of data
	//
	// Up to 1000 data items can be added.
	//
	// Return value:
	// 0 - success
	// 1 - no chart type specified
	// 2 - could not open filename
	// 3 - maximum number of data items reached
	// 101...
	//	  - line (101 - 100), ie line 1 contains invalid data


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_DataSeparator([MarshalAs(UnmanagedType.LPStr)] String separator);
	// Set the data separator text that is used to delineate data fields when loading in data 
	// from an external file, by default this is a comma
	//
	// A maximum of 10 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	public static UInt32 SORT_ASCENDING		    = 1;
	public static UInt32 SORT_DESCENDING		= 2;
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_DataSort(UInt32 field, UInt32 order);
	// Specify that the data items are to be sorted before being displayed within the chart
	//
	// field must be either 1 or 2
	//
	// 0 - success
	// 1 - field invalid
	// 2 - order invalid


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_Log([MarshalAs(UnmanagedType.LPStr)] String logFilename);
	// Information and error messages are appended to the end of the file specified (with a timestamp).
	//
	// Return value:
	// 0 - success
	// 1 - invalid logFilename


	// *************************************************************************
	// Area Chart Specific
	// *************************************************************************
	[DllImport("PDFChart.dll")]
    public static extern UInt32 PDFC_AreaDatum([MarshalAs(UnmanagedType.LPStr)] String label, double value);
    // Add an item of area data.
	//
	// Up to 1000 data items can be added.
	//
	// Return value:
	// 0 - success
	// 1 - area chart type not specified
	// 2 - maximum number of data items already reached
	// 3 - label invalid


	[DllImport("PDFChart.dll")]
    public static extern UInt32 PDFC_Area(double lineRed, double lineGreen, double lineBlue, double lineThickness, double fillRed, double fillGreen, double fillBlue);
	// Specifies how the area under the data points is to be filled.
	//
	// Return value:
	// 0 - success
	// 1 - invalid lineRed
	// 2 - invalid lineGreen
	// 3 - invalid lineBlue
	// 4 - invalid lineThickness
	// 5 - invalid fillRed
	// 6 - invalid fillGreen
	// 7 - invalid fillBlue


	// *************************************************************************
	// Line Chart Specific
	// *************************************************************************
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_LineDatum([MarshalAs(UnmanagedType.LPStr)] String label, double value);
	// Add an item of line data.
	//
	// Up to 1000 data items can be added.
	//
	// Return value:
	// 0 - success
	// 1 - line chart type not specified
	// 2 - maximum number of data items already reached
	// 3 - label invalid


    [DllImport("PDFChart.dll")]
    public static extern UInt32 PDFC_Line(double lineRed, double lineGreen, double lineBlue, double lineThickness);
    // Specifies the line color and thickness that connects all of the data points together.
    //
    // Return value:
    // 0 - success
    // 1 - invalid lineRed
    // 2 - invalid lineGreen
    // 3 - invalid lineBlue
    // 4 - invalid lineThickness


    public static UInt32 LINE_POINT_STYLE_FILLED_CIRCLE		= 1;
	public static UInt32 LINE_POINT_STYLE_OUTLINE_CIRCLE	= 2;
	public static UInt32 LINE_POINT_STYLE_FILLED_SQUARE		= 3;
	public static UInt32 LINE_POINT_STYLE_OUTLINE_SQUARE	= 4;
	public static UInt32 LINE_POINT_STYLE_CROSS				= 5;
	public static UInt32 LINE_POINT_STYLE_FILLED_DIAMOND	= 6;
	public static UInt32 LINE_POINT_STYLE_OUTLINE_DIAMOND	= 7;
    [DllImport("PDFChart.dll")]
    public static extern UInt32 PDFC_LineMarker(double markerRed, double markerGreen, double markerBlue, double size, UInt32 markerStyle, double outlineThickness);
	// Specifies a marker to be displayed on the line at the data point position.
	//
	// Return value:
	// 0 - success
	// 1 - invalid markerRed
	// 2 - invalid markerGreen
	// 3 - invalid markerBlue
	// 4 - invalid size
	// 5 - invalid markerStyle
	// 6 - invalid outlineThickness

    
    // *************************************************************************
	// Bar Chart Specific
	// *************************************************************************
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_BarDatum([MarshalAs(UnmanagedType.LPStr)] String label, double value);
	// Add an item of bar data.
	//
	// Up to 1000 data items can be added.
	//
	// Return value:
	// 0 - success
	// 1 - bar chart type not specified
	// 2 - maximum number of data items already reached
	// 3 - label invalid


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_BarColor(double fromRed, double fromGreen, double fromBlue, double toRed, double toGreen, double toBlue);
	// Sets a color (range) for a bar
	//
	// Up to 50 bar colors can be defined
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
	//
	// Return value:
	// 0 - success
	// 1 - maximum number of bar colors already specified
	// 2 - from red invalid
	// 3 - from green invalid
	// 4 - from blue invalid
	// 5 - to red invalid
	// 6 - to green invalid
	// 7 - to blue invalid


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_BarSpacing(UInt32 spacing);
	// Sets the amount of spacing between bars (bar size automatically calculated from this)
	//
	// Return value:
	// 0 - success
	// 1 - invalid spacing, must be between 0 and 500 inclusive


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_BarSize(UInt32 size);
	// Sets the bar size (bar spacing automatically calculated from this)
	//
	// Return value:
	// 0 - success
	// 1 - invalid size, must be between 1 and 500 inclusive


	public static UInt32 LABEL_AT_START					    = 1;
	public static UInt32 LABEL_AT_END						= 2;
	public static UInt32 LABEL_AT_CENTER					= 3;
	public static UInt32 LABEL_AT_AXES						= 4;
	public static UInt32 LABEL_AT_AXES_AND_START			= 5;
	public static UInt32 LABEL_AT_AXES_AND_END				= 6;
	public static UInt32 LABEL_AT_AXES_AND_CENTER			= 7;
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_BarLabel(UInt32 labelPosition, [MarshalAs(UnmanagedType.LPStr)] String format);
	// Set the position and label style
	//
	// Return value:
	// 0 - success
	// 1 - label position not valid
	// 2 - invalid format


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_BarBorder(double width, double red, double green, double blue);
	// Set the bar border width and color
	//
	// width must be > 0.0 and <= 100.0
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
	//
	// 0 - success
	// 1 - width invalid
	// 2 - red invalid
	// 3 - green invalid
	// 4 - blue invalid


	// *************************************************************************
	// Axes and Labels
	// *************************************************************************
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_ChartBackground(double fromRed, double fromGreen, double fromBlue, double toRed, double toGreen, double toBlue);
	// Sets the background color (range) for the chart
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
	//
	// Return value:
	// 0 - success
	// 1 - from red invalid
	// 2 - from green invalid
	// 3 - from blue invalid
	// 4 - to red invalid
	// 5 - to green invalid
	// 6 - to blue invalid


	public static UInt32 VERTICAL_ALIGNMENT_TOP			    = 1;
	public static UInt32 VERTICAL_ALIGNMENT_MIDDLE			= 2;
	public static UInt32 VERTICAL_ALIGNMENT_BOTTOM			= 3;

	public static UInt32 HORIZONTAL_ALIGNMENT_LEFT			= 1;
	public static UInt32 HORIZONTAL_ALIGNMENT_CENTER		= 2;
	public static UInt32 HORIZONTAL_ALIGNMENT_RIGHT		    = 3;
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_ChartHeading(UInt32 verticalAlignment, UInt32 horizontalAlignment);
	// Sets the chart heading position
	//
	// vertical alignment must be either top or bottom (NOT middle)
	//
	// Return value:
	// 0 - success
	// 1 - vertical alignment invalid
	// 2 - horizontal alignment invalid


	public static UInt32 FONT_ID_COURIER					= 1;
	public static UInt32 FONT_ID_COURIER_BOLD				= 2;
	public static UInt32 FONT_ID_COURIER_BOLDOBLIQUE		= 3;
	public static UInt32 FONT_ID_COURIER_OBLIQUE			= 4;
	public static UInt32 FONT_ID_HELVETICA					= 5;
	public static UInt32 FONT_ID_HELVETICA_BOLD			    = 6;
	public static UInt32 FONT_ID_HELVETICA_BOLDOBLIQUE		= 7;
	public static UInt32 FONT_ID_HELVETICA_OBLIQUE			= 8;
	public static UInt32 FONT_ID_TIMES_ROMAN				= 9;
	public static UInt32 FONT_ID_TIMES_BOLD				    = 10;
	public static UInt32 FONT_ID_TIMES_ITALIC				= 11;
	public static UInt32 FONT_ID_TIMES_BOLDITALIC			= 12;
	public static UInt32 FONT_ID_SYMBOL					    = 13;
	public static UInt32 FONT_ID_ZAPFDINGBATS				= 14;

	public static UInt32 TEXT_STYLE_NORMAL					= 1;
	public static UInt32 TEXT_STYLE_STROKE					= 2;
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_HeadingTitle(   UInt32 size, UInt32 fontID, double fillRed, double fillGreen, double fillBlue, UInt32 style, double otherRed, double otherGreen, double otherBlue);
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_HeadingSubTitle(UInt32 size, UInt32 fontID, double fillRed, double fillGreen, double fillBlue, UInt32 style, double otherRed, double otherGreen, double otherBlue);
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesLabelX(     UInt32 size, UInt32 fontID, double fillRed, double fillGreen, double fillBlue, UInt32 style, double otherRed, double otherGreen, double otherBlue);
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesLabelY(     UInt32 size, UInt32 fontID, double fillRed, double fillGreen, double fillBlue, UInt32 style, double otherRed, double otherGreen, double otherBlue);
	// Sets the appropriate text style
	//
	// size must be between 1 and 300 inclusive
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
	//
	// other color is only required if the style is stroke
	//
	// Return value:
	// 0 - success
	// 1 - invalid size
	// 2 - invalid font 
	// 3 - fill red invalid
	// 4 - fill green invalid
	// 5 - fill blue invalid
	// 6 - invalid style
	// 7 - other red invalid
	// 8 - other green invalid
	// 9 - other blue invalid


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesCaptionX(UInt32 size, UInt32 fontID, double fillRed, double fillGreen, double fillBlue, UInt32 style, double otherRed, double otherGreen, double otherBlue, UInt32 horizontalAlignment, [MarshalAs(UnmanagedType.LPStr)] String label);
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesCaptionY(UInt32 size, UInt32 fontID, double fillRed, double fillGreen, double fillBlue, UInt32 style, double otherRed, double otherGreen, double otherBlue, UInt32 verticalAlignment, [MarshalAs(UnmanagedType.LPStr)] String label);
	// Sets the appropriate axes label style and text
	//
	// size must be between 1 and 300 inclusive
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
	//
	// other color is only required if the style is stroke
	//
	// Return value:
	// 0 - success
	// 1 - invalid size
	// 2 - invalid font 
	// 3 - fill red invalid
	// 4 - fill green invalid
	// 5 - fill blue invalid
	// 6 - invalid style
	// 7 - other red invalid
	// 8 - other green invalid
	// 9 - other blue invalid
	// 10 - invalid horizontal/vertical alignment
	// 11 - label is invalid


	public static UInt32 AXES_LINE_XY		= 1;
	public static UInt32 AXES_LINE_FULL	    = 2;
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesLine(double width, double red, double green, double blue, UInt32 format);
	// Sets the width, color and style for the axes boundary lines surrounding the chart area
	//
	// width must be between 0.1 and 100.0 inclusive
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
	//
	// Return value:
	// 0 - success
	// 1 - invalid width
	// 2 - red invalid
	// 3 - green invalid
	// 4 - blue invalid
	// 5 - invalid line format


	public static UInt32 AXES_SCALE_FROM_ZERO				= 1;
	public static UInt32 AXES_SCALE_UNDER_LOWEST_VALUE		= 2;
	public static UInt32 AXES_SCALE_RANGE					= 3;
	public static UInt32 AXES_SCALE_EITHER_SIDE				= 4;

    [DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesScale(UInt32 scale, double value1, double value2);
	// Sets the width, color and style for the axes boundary lines surrounding the chart area
	//
	// if scale is AXES_SCALE_FROM_ZERO then value1 and value2 are not used
	// if scale is AXES_SCALE_UNDER_LOWEST_VALUE then value1 is an integer percentage from 0 to 100%, value2 is not used
	// if scale is AXES_SCALE_RANGE then the axes range is from value1 to value2
	//
	// Return value:
	// 0 - success
	// 1 - invalid scale type
	// 2 - invalid percentage


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesDivisions(UInt32 divisions);
	// Sets the number of divisions in the axes scale
	//
	// divisions must be between 1 and 100 inclusive
	//
	// Return value:
	// 0 - success
	// 1 - invalid divisions


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_DecimalPoints(UInt32 points);
	// Sets the number of decimal points to be displayed with a real number
	//
	// points must be between 0 and 9 inclusive
	//
	// Return value:
	// 0 - success
	// 1 - invalid points


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesGridLineStyle(UInt32 dash, UInt32 gap, UInt32 offset);
	// Sets the dashed line style for the grid lines
	//
	// all parameters must be between 0 and 100 inclusive
	//
	// Return value:
	// 0 - success
	// 1 - invalid dash
	// 2 - invalid gap
	// 3 - invalid offset


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesGridLine(double width, double red, double green, double blue);
	// Sets the width and color of the axes grid lines that are drawn within the chart area
	//
	// width must be between 0.1 and 100.0 inclusive
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
	//
	// Return value:
	// 0 - success
	// 1 - invalid width
	// 2 - red invalid
	// 3 - green invalid
	// 4 - blue invalid


	public static UInt32 AXES_LABEL_Y_POSITION_TO_LEFT = 1;
	public static UInt32 AXES_LABEL_Y_POSITION_TO_RIGHT = 2;
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesLabelYPosition(UInt32 position);
	// Controls which side of the chart the Y axis label is displayed
	//
	// position must be either AXES_LABEL_Y_POSITION_TO_LEFT or AXES_LABEL_Y_POSITION_TO_RIGHT
	//
	// Return value:
	// 0 - success
	// 1 - invalid position


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_AxesLabelSpacing(UInt32 nth);
	// Controls the display of the X axis data labels (if the chart type supports this)
	// so that it displays every nth label on the axes which is useful if there are a 
	// lot of labels to display which would otherwise overwrite each other
	//
	// nth must be between 1 and 50 inclusive
	//
	// Return value:
	// 0 - success
	// 1 - nth is invalid


	// *************************************************************************
	// Pie Chart Specific
	// *************************************************************************
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_PieDatum([MarshalAs(UnmanagedType.LPStr)] String label, double value);
	// Add an item of pie data.
	//
	// Up to 1000 data items can be added.
	//
	// Return value:
	// 0 - success
	// 1 - pie chart type not specified
	// 2 - maximum number of data items already reached
	// 3 - label invalid


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_PieColor(double red, double green, double blue);
	// Sets a color for a pie segment
	//
	// Up to 50 bar colors can be defined
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
	// 
	// Return value:
	// 0 - success
	// 1 - maximum number of pie colors already specified
	// 2 - red invalid
	// 3 - green invalid
	// 4 - blue invalid


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_PieOutline(double borderWidth, double red, double green, double blue);
	// Sets a color for a pie segment
	//
	// borderWidth must be between 0.0 and 100.0 inclusive
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive.
	//
	// Return value:
	// 0 - success
	// 1 - border width invalid
	// 2 - red invalid
	// 3 - green invalid
	// 4 - blue invalid


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_PiePageMargin(double marginSize);
	// Sets the minimum spacing between the edge of the page and the chart
	//
	// margin size must be between 0.0 and 100.0 inclusive
	//
	// Return value:
	// 0 - success
	// 1 - margin size invalid


	public static UInt32 LABEL_INSIDE						= 8;
	public static UInt32 LABEL_OUTSIDE						= 9;
	public static UInt32 LABEL_SPOKE						= 10;
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_PieLabel(UInt32 labelPosition, [MarshalAs(UnmanagedType.LPStr)] String format, UInt32 size, UInt32 fontID, double fillRed, double fillGreen, double fillBlue, UInt32 style, double otherRed, double otherGreen, double otherBlue);
	// Sets the label text style
	//
	// size must be between 1 and 300 inclusive
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
	//
	// other color is only required if the style is stroke
	//
	// Return value:
	// 0 - success
	// 1 - invalid size
	// 2 - invalid font 
	// 3 - fill red invalid
	// 4 - fill green invalid
	// 5 - fill blue invalid
	// 6 - invalid style
	// 7 - other red invalid
	// 8 - other green invalid
	// 9 - other blue invalid
	// 10 - invalid label format
	// 11 - invalid label position


	// *************************************************************************
	// Legends
	// *************************************************************************
	public static UInt32 LEGEND_NONE						= 0;
	public static UInt32 LEGEND_ABOVE						= 1;
	public static UInt32 LEGEND_BELOW						= 2;
	public static UInt32 LEGEND_LEFT						= 3;
	public static UInt32 LEGEND_RIGHT						= 4;
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_Legend(UInt32 legendPosition, [MarshalAs(UnmanagedType.LPStr)] String format, double outlineRed, double outlineGreen, double outlineBlue, double outlineWidth, double backgroundRed, double backgroundGreen, double backgroundBlue, UInt32 size, UInt32 fontID, double fillRed, double fillGreen, double fillBlue, UInt32 style, double otherRed, double otherGreen, double otherBlue);
	// Legend box settings
	//
	// size must be between 1 and 300 inclusive
	//
	// Each color component (red, green, blue) value must be between 0.0 and 1.0 inclusive
	//
	// other color is only required if the style is stroke
	//
	// Return value:
   	// 0 - success
	// 1 - legend position invalid
	// 2 - outline red invalid
	// 3 - outline green invalid
	// 4 - outline blue invalid
	// 5 - invalid outline width
	// 6 - background red invalid
	// 7 - background green invalid
	// 8 - background blue invalid
	// 9 - invalid legend format
	// 10 - invalid size
	// 11 - invalid font 
	// 12 - fill red invalid
	// 13 - fill green invalid
	// 14 - fill blue invalid
	// 15 - invalid style
	// 16 - other red invalid
	// 17 - other green invalid
	// 18 - other blue invalid
    

	// *************************************************************************
	// Numerical Analyses
	// *************************************************************************
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_LineOfBestFit(double lineRed, double lineGreen, double lineBlue, double lineThickness);
	// Specifies the line thickness and color that is used to display the "line of best fit".
	//
	// Return value:
	// 0 - success
	// 1 - invalid lineRed
	// 2 - invalid lineGreen
	// 3 - invalid lineBlue
	// 4 - invalid lineThickness


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_MovingAverageLine(UInt32 samplePoints, double lineRed, double lineGreen, double lineBlue, double lineThickness);
    // The moving average at any given point is the average of that point and the preceeding <samplePoints - 1> data items.
    // This means that the first moving average point that can be plotted is not at the first position on the chart but at the <samplePoints> position.
    //
    // Return value:
    // 0 - success
    // 1 - invalid lineRed
    // 2 - invalid lineGreen
    // 3 - invalid lineBlue
    // 4 - invalid lineThickness
    // 5 - invalid samples


    // Following values already defined above
    // LINE_POINT_STYLE_FILLED_CIRCLE
    // LINE_POINT_STYLE_OUTLINE_CIRCLE
    // LINE_POINT_STYLE_FILLED_SQUARE
    // LINE_POINT_STYLE_OUTLINE_SQUARE
    // LINE_POINT_STYLE_CROSS
    // LINE_POINT_STYLE_FILLED_DIAMOND
    // LINE_POINT_STYLE_OUTLINE_DIAMOND
    [DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_MovingAverageLineMarker(UInt32 markerStyle, double markerRed, double markerGreen, double markerBlue, double markerSize, double outlineThickness);
    // This is optional and specifies a marker to be displayed on the moving average line at the data point position.
    //
    // Return value:
    // 0 - success
    // 1 - invalid markerStyle
    // 2 - invalid markerRed
    // 3 - invalid markerGreen
    // 4 - invalid markerBlue
    // 5 - invalid markerSize
    // 6 - invalid outlineThickness
    

	// *************************************************************************
	// PDF Settings
	// *************************************************************************
	public static UInt32 PDF_PERMISSION_READ_ONLY       = 0;
	public static UInt32 PDF_PERMISSION_EDIT		    = 1; 
	public static UInt32 PDF_PERMISSION_EDIT_EXTRA      = 2;
	public static UInt32 PDF_PERMISSION_COPY            = 4;
	public static UInt32 PDF_PERMISSION_PRINT           = 8;
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_SetPermissions(UInt32 iPermissions);
	// Allows the setting of any combination of permissions in one go
	//
    // Return value:
    // 0 - success
    // 1 - invalid permissions

	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPermissionEdit();
	// Allows editing/changing of the PDF document but NOT adding or changing of text 
	// notes and AcroForm fields.
	//
	// Return value: none 


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPermissionEditExtra();
	// Allows the adding and changing of text notes and AcroForm fields within a PDF document.
	//
	// Return value: none 


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPermissionCopy();
	// Allows the copying of text and graphics from the PDF document.
	//
	// Return value: none 


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPermissionPrint();
	// Allows printing of the PDF document.
	//
	// Return value: none 


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_SetOwnerPassword([MarshalAs(UnmanagedType.LPStr)] String password);
	// The owner of a PDF document would enter this password in order to view it
	// and make changes and perform actions that may be restricted to a normal user.
	//
	// A maximum of 32 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_SetUserPassword([MarshalAs(UnmanagedType.LPStr)] String password);
	// In order that only the intended user can view the PDF document, they must type
	// in this password, otherwise the user is not allowed to read the PDF document.
	//
	// A maximum of 32 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	// *************************************************************************
	// PDF Meta Information
	// *************************************************************************
	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_SetProducer([MarshalAs(UnmanagedType.LPStr)] String producer);
	// The name of the application that converted the document from its native format to PDF.
	//
	// A maximum of 256 characters can be used.
	// 
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_SetCreator([MarshalAs(UnmanagedType.LPStr)] String creator);
	// If the document was converted into a PDF document from another form, this is 
	// usually the name of the application that created the original document.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_SetAuthor([MarshalAs(UnmanagedType.LPStr)] String author);
	// The name of the person who created the PDF document.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_SetTitle([MarshalAs(UnmanagedType.LPStr)] String title);
	// The PDF document's title.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_SetSubject([MarshalAs(UnmanagedType.LPStr)] String subject);
	// The PDF document's subject.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("PDFChart.dll")]
	public static extern UInt32 PDFC_SetKeywords([MarshalAs(UnmanagedType.LPStr)] String keywords);
	// A list of keywords associated with the PDF document.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetCreationDate();
	// The date that the PDF document was created.
	//
	// This is set using the current local time of the PC.
	//
	// Return value: none


	// *************************************************************************
	// PDF Viewer Preferences
	// *************************************************************************
	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetViewerPreferenceCenterWindow();
	// The window displaying the PDF document should be displayed in the center of 
	// the computer's screen.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetViewerPreferenceHideToolbar();
	// The PDF viewer's toolbar should be hidden when the PDF document is active.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetViewerPreferenceHideMenubar();
	// The PDF viewer's menubar should be hidden when the PDF document is active.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetViewerPreferenceHideWindowUI();
	// The user interface elements within the PDF document's window should be hidden.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetViewerPreferenceFitWindow();
	// The PDF viewer should resize the window displaying the PDF document to fit the 
	// size of the first displayed page of the PDF document.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPageModeOutlines();
	// The PDF viewer should show the outline (ie bookmark) navigation item when the 
	// PDF document is open.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPageModeNone();
	// The PDF viewer should not show the outline (ie bookmark) or thumbnail navigation
	// items when the PDF document is open.
	//
	// This is the default if no other page mode is specified.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPageModeUseThumbs();
	// The PDF viewer should show the thumbnail navigation item when the PDF document 
	// is open.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPageModeFullScreen();
	// The PDF viewer should open the PDF document in full-screen mode without showing 
	// the menu bar, window controls or any other window.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPageLayoutSinglePage();
	// Display the pages one page at a time.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPageLayoutOneColumn();
	// Display the pages in one column.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPageLayoutTwoColumnLeft();
	// Display the pages in two columns, with odd-numbered pages on the left.
	//
	// Return value: none


	[DllImport("PDFChart.dll")]
	public static extern void PDFC_SetPageLayoutTwoColumnRight();
	// Display the pages in two columns, with odd-numbered pages on the right.
	//
	// Return value: none


	// *************************************************************************
	// Specifies the name and location of the produced PDF document, 
	// *************************************************************************
	public static UInt32 OPTION_NONE			= 0;
	public static UInt32 OPTION_OPEN_PDF		= 1;
	public static UInt32 OPTION_RESET		    = 2;
	[DllImport("PDFChart.dll")]
    public static extern UInt32 PDFC_MakePDF([MarshalAs(UnmanagedType.LPStr)] String output, UInt32 options, StringBuilder errorText, int maxErrorTextSize);
	// Generate the output PDF according to the settings already selected through
	// the Application Programming Interface functions above.
	//
    // To have the output PDF open in the default PDF viewer set the OPTION_OPEN_PDF
    // bit flag in the options parameter.
	//
    // To have all settings applied reset after PDF has been generated set the OPTION_RESET
    // bit flag in the options parameter.
	//
	// Return value:
	// 0 - success
	// 1 - internal error - see errorText for details (unless NULL passed)
	// 2 - output pdf could not be opened
	// 3 - chart type not specified
	// 4 - chart style not specified
	// 5 - no data items to chart
	// 6 - no output pdf filename specified
	// 7 - no bar colors specified
	// 8 - no pie colors specified
}
